﻿<%@ Page Language="C#" AutoEventWireup="true" CodeBehind="UseGoogleMap.aspx.cs" Inherits="CSSamples.Samples.Layers.UseGoogleMap" %>

<%@ Register Assembly="WebEdition" Namespace="ThinkGeo.MapSuite.WebEdition" TagPrefix="cc1" %>
<html xmlns="http://www.w3.org/1999/xhtml">
<head id="Head1" runat="server">
    <link href="~/theme/default/samplepic/style.css" rel="stylesheet" type="text/css" />
    <title>Use Google Map</title>
    <style>
        #controlToggle li
        {
            list-style: none;
        }
        p
        {
            width: 512px;
        }
        #options
        {
            position: relative;
            width: 512px;
        }
        #measurement
        {
            bottom: 0;
            display: block;
            font-family: Arial,Helvetica,sans-serif;
            font-size: x-small;
            position: absolute;
            left: 3px;
            z-index: 9999;
        }
    </style>
</head>
<body>
    <form id="form1" runat="server">
    <asp:ScriptManager ID="ScriptManager1" runat="server">
    </asp:ScriptManager>
    <cc1:Map ID="Map1" runat="server" Height="600" Width="800">
    </cc1:Map>
    <div>
        <ul id="controlToggle">
            <li>
                <input type="radio" name="type" value="none" id="noneToggle" onclick="deactivate();"
                    checked="checked" />
                <label for="noneToggle">
                    navigate</label>
            </li>
            <li>
                <input type="radio" name="type" value="line" id="lineToggle" onclick="activate();" />
                <label for="lineToggle">
                    measure distance</label>
            </li>
        </ul>
    </div>
    <div id="measurement" style="float: left;">
    </div>

    <script type="text/javascript">
        var toExternal = true;
        var toInternal = false;
        var measureLineControl;
        var displayLayer;
        var transform = function(x, y, bToExternal) {
            var lonlat = new OpenLayers.Geometry.Point(x, y);
            var externalProj = new OpenLayers.Projection('EPSG:900913');
            var internalProj = new OpenLayers.Projection('EPSG:4326');

            var newLonLat = null;
            if (bToExternal) {
                newLonlat = OpenLayers.Projection.transform(lonlat, internalProj, externalProj);
            }
            else {
                newLonlat = OpenLayers.Projection.transform(lonlat, externalProj, internalProj);
            }

            return newLonlat;
        }

        function OnMapCreating(map) {
            // Display mouse position in internal projection  
            OpenLayers.Control.MousePosition = OpenLayers.Class(OpenLayers.Control.MousePosition, {
                formatOutput: function(lonLat) {
                    var newHtml = '';
                    var newPoint = transform(lonLat.lon, lonLat.lat, toInternal); //see Projection.js for this transform method
                    var newHtml = newPoint.y.toFixed(5) + ', ' + newPoint.x.toFixed(5);
                    return newHtml;
                }
            }
        );
            //.. other code

        }
        function OnMapCreated(map) {
            tgMap = map;
            //.. other code

        }
        /*<---------------------------- Measure distance by drawing a line on the map STARTS------------------------>*/
        // ctrl up
        var defaultKeyUp = function(evt) {
            if (evt.keyCode == 17) {
                Map1.SetDrawMode("Normal");
                deactivate();
                //hide the measurement on the lower left of the page
                document.getElementById('measurement').style.display = "none"; // see the bottom for measure in css

            }
        } //end defaultKeUp
        //ctrl down
        var defaultKeyPress = function(evt) {
            //ctrl down
            if (evt.keyCode == 17) {
                Map1.SetDrawMode("Line");
                activate();
            }

        } //end defaultKeyPress
        //Activate distance measurement by drawing a line
        function activate() {
            if (!measureLineControl) {
                if (displayLayer == null)
                    displayLayer = new OpenLayers.Layer.Vector('displayLayer');

                measureLineControl = new OpenLayers.Control.Measure(OpenLayers.Handler.Path, { persist: true, geodesic: true });
                measureLineControl.events.on({
                    "measure": handleMeasurements,
                    "measurepartial": handleMeasurements
                });

                tgMap.addControl(measureLineControl);
            }
            measureLineControl.activate();

        } //End activate
        //Deactivate distance measurement 
        function deactivate() {
            if (measureLineControl) {
                measureLineControl.deactivate();
            }

        } //End deactivate
        //Measure distance and Display the distance on lower left coner of the map 
        function handleMeasurements(event) {
            var geometry = event.geometry;
            var units = event.units;
            var order = event.order;
            var measure = event.measure;
            var kilometers;
            var meters;
            var miles;
            var feets;
            if (units == "km") {

                kilometers = measure;
                meters = kilometers * 1000;
                miles = kilometers * 0.621371192;
                feets = miles * 5280;
            }
            else//units is m
            {
                meters = measure;
                kilometers = measure / 1000;
                miles = measure * 0.621371192 / 1000;
                feets = miles * 5280;
            }

            var element = document.getElementById('measurement');
            document.getElementById('measurement').style.display = "inline";
            var out = "";

            if (order == 1) //linear
            {
                out += "distance: " + kilometers.toFixed(4) + "km," + miles.toFixed(4) + "miles," + feets.toFixed(4) + "feet";

            } else {
                out += "distance: " + kilometers.toFixed(4) + "km," + miles.toFixed(4) + "miles," + feets.toFixed(4) + "feet" + "<sup>2</" + "sup>";
            }


            element.innerHTML = out;

        } // End handleMeasurements
    </script>

    <%--   <Description:DescriptionPanel ID="DescPanel" runat="server">
        This sample displays a google map. Click buttons below to switch between different Google maps.
        <br />
        <br />
        <asp:Button CssClass="btn" ID="btnRoad" runat="server" Text="Normal" OnClientClick="Map1.SetCurrentBackgroundMapType(G_NORMAL_MAP); return false;" />
        <asp:Button CssClass="btn" ID="btnAerial" runat="server" Text="Hybrid" OnClientClick="Map1.SetCurrentBackgroundMapType(G_HYBRID_MAP); return false;" /><br />
        <asp:Button CssClass="btn" ID="btnSatellite" runat="server" Text="Satellite" OnClientClick="Map1.SetCurrentBackgroundMapType(G_SATELLITE_MAP); return false;" />
        <asp:Button CssClass="btn" ID="btnPhysical" runat="server" Text="Physical" OnClientClick="Map1.SetCurrentBackgroundMapType(G_PHYSICAL_MAP); return false;" />
    </Description:DescriptionPanel>--%>
    </form>
</body>
</html>
